# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from onepanel.core.api.configuration import Configuration


class CronWorkflow(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'uid': 'str',
        'manifest': 'str',
        'workflow_execution': 'WorkflowExecution',
        'labels': 'list[KeyValue]',
        'namespace': 'str'
    }

    attribute_map = {
        'name': 'name',
        'uid': 'uid',
        'manifest': 'manifest',
        'workflow_execution': 'workflowExecution',
        'labels': 'labels',
        'namespace': 'namespace'
    }

    def __init__(self, name=None, uid=None, manifest=None, workflow_execution=None, labels=None, namespace=None, local_vars_configuration=None):  # noqa: E501
        """CronWorkflow - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._uid = None
        self._manifest = None
        self._workflow_execution = None
        self._labels = None
        self._namespace = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if uid is not None:
            self.uid = uid
        if manifest is not None:
            self.manifest = manifest
        if workflow_execution is not None:
            self.workflow_execution = workflow_execution
        if labels is not None:
            self.labels = labels
        if namespace is not None:
            self.namespace = namespace

    @property
    def name(self):
        """Gets the name of this CronWorkflow.  # noqa: E501


        :return: The name of this CronWorkflow.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CronWorkflow.


        :param name: The name of this CronWorkflow.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def uid(self):
        """Gets the uid of this CronWorkflow.  # noqa: E501


        :return: The uid of this CronWorkflow.  # noqa: E501
        :rtype: str
        """
        return self._uid

    @uid.setter
    def uid(self, uid):
        """Sets the uid of this CronWorkflow.


        :param uid: The uid of this CronWorkflow.  # noqa: E501
        :type: str
        """

        self._uid = uid

    @property
    def manifest(self):
        """Gets the manifest of this CronWorkflow.  # noqa: E501


        :return: The manifest of this CronWorkflow.  # noqa: E501
        :rtype: str
        """
        return self._manifest

    @manifest.setter
    def manifest(self, manifest):
        """Sets the manifest of this CronWorkflow.


        :param manifest: The manifest of this CronWorkflow.  # noqa: E501
        :type: str
        """

        self._manifest = manifest

    @property
    def workflow_execution(self):
        """Gets the workflow_execution of this CronWorkflow.  # noqa: E501


        :return: The workflow_execution of this CronWorkflow.  # noqa: E501
        :rtype: WorkflowExecution
        """
        return self._workflow_execution

    @workflow_execution.setter
    def workflow_execution(self, workflow_execution):
        """Sets the workflow_execution of this CronWorkflow.


        :param workflow_execution: The workflow_execution of this CronWorkflow.  # noqa: E501
        :type: WorkflowExecution
        """

        self._workflow_execution = workflow_execution

    @property
    def labels(self):
        """Gets the labels of this CronWorkflow.  # noqa: E501


        :return: The labels of this CronWorkflow.  # noqa: E501
        :rtype: list[KeyValue]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this CronWorkflow.


        :param labels: The labels of this CronWorkflow.  # noqa: E501
        :type: list[KeyValue]
        """

        self._labels = labels

    @property
    def namespace(self):
        """Gets the namespace of this CronWorkflow.  # noqa: E501


        :return: The namespace of this CronWorkflow.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this CronWorkflow.


        :param namespace: The namespace of this CronWorkflow.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CronWorkflow):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CronWorkflow):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import onepanel.core.api
from onepanel.core.api.api.namespace_service_api import NamespaceServiceApi  # noqa: E501
from onepanel.core.api.rest import ApiException


class TestNamespaceServiceApi(unittest.TestCase):
    """NamespaceServiceApi unit test stubs"""

    def setUp(self):
        self.api = onepanel.core.api.api.namespace_service_api.NamespaceServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_namespace(self):
        """Test case for create_namespace

        """
        pass

    def test_list_namespaces(self):
        """Test case for list_namespaces

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onepanel.core.api
from onepanel.core.api.models.create_inference_service_request import CreateInferenceServiceRequest  # noqa: E501
from onepanel.core.api.rest import ApiException

class TestCreateInferenceServiceRequest(unittest.TestCase):
    """CreateInferenceServiceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateInferenceServiceRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = onepanel.core.api.models.create_inference_service_request.CreateInferenceServiceRequest()  # noqa: E501
        if include_optional :
            return CreateInferenceServiceRequest(
                namespace = '0', 
                name = '0', 
                default_transformer_image = '0', 
                predictor = onepanel.core.api.models.inference_service_predictor.InferenceServicePredictor(
                    name = '0', 
                    runtime_version = '0', 
                    storage_uri = '0', 
                    node_selector = '0', 
                    min_cpu = '0', 
                    min_memory = '0', 
                    max_cpu = '0', 
                    max_memory = '0', ), 
                transformer = onepanel.core.api.models.inference_service_transformer.InferenceServiceTransformer(
                    containers = [
                        onepanel.core.api.models.container.Container(
                            image = '0', 
                            name = '0', 
                            env = [
                                onepanel.core.api.models.env.Env(
                                    name = '0', 
                                    value = '0', )
                                ], )
                        ], 
                    min_cpu = '0', 
                    min_memory = '0', 
                    max_cpu = '0', 
                    max_memory = '0', )
            )
        else :
            return CreateInferenceServiceRequest(
        )

    def testCreateInferenceServiceRequest(self):
        """Test CreateInferenceServiceRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onepanel.core.api
from onepanel.core.api.models.labels import Labels  # noqa: E501
from onepanel.core.api.rest import ApiException

class TestLabels(unittest.TestCase):
    """Labels unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Labels
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = onepanel.core.api.models.labels.Labels()  # noqa: E501
        if include_optional :
            return Labels(
                items = [
                    onepanel.core.api.models.key_value.KeyValue(
                        key = '0', 
                        value = '0', )
                    ]
            )
        else :
            return Labels(
        )

    def testLabels(self):
        """Test Labels"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from onepanel.core.api.configuration import Configuration


class InferenceServicePredictor(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'runtime_version': 'str',
        'storage_uri': 'str',
        'node_selector': 'str',
        'min_cpu': 'str',
        'min_memory': 'str',
        'max_cpu': 'str',
        'max_memory': 'str'
    }

    attribute_map = {
        'name': 'name',
        'runtime_version': 'runtimeVersion',
        'storage_uri': 'storageUri',
        'node_selector': 'nodeSelector',
        'min_cpu': 'minCpu',
        'min_memory': 'minMemory',
        'max_cpu': 'maxCpu',
        'max_memory': 'maxMemory'
    }

    def __init__(self, name=None, runtime_version=None, storage_uri=None, node_selector=None, min_cpu=None, min_memory=None, max_cpu=None, max_memory=None, local_vars_configuration=None):  # noqa: E501
        """InferenceServicePredictor - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._runtime_version = None
        self._storage_uri = None
        self._node_selector = None
        self._min_cpu = None
        self._min_memory = None
        self._max_cpu = None
        self._max_memory = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if runtime_version is not None:
            self.runtime_version = runtime_version
        if storage_uri is not None:
            self.storage_uri = storage_uri
        if node_selector is not None:
            self.node_selector = node_selector
        if min_cpu is not None:
            self.min_cpu = min_cpu
        if min_memory is not None:
            self.min_memory = min_memory
        if max_cpu is not None:
            self.max_cpu = max_cpu
        if max_memory is not None:
            self.max_memory = max_memory

    @property
    def name(self):
        """Gets the name of this InferenceServicePredictor.  # noqa: E501


        :return: The name of this InferenceServicePredictor.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InferenceServicePredictor.


        :param name: The name of this InferenceServicePredictor.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def runtime_version(self):
        """Gets the runtime_version of this InferenceServicePredictor.  # noqa: E501


        :return: The runtime_version of this InferenceServicePredictor.  # noqa: E501
        :rtype: str
        """
        return self._runtime_version

    @runtime_version.setter
    def runtime_version(self, runtime_version):
        """Sets the runtime_version of this InferenceServicePredictor.


        :param runtime_version: The runtime_version of this InferenceServicePredictor.  # noqa: E501
        :type: str
        """

        self._runtime_version = runtime_version

    @property
    def storage_uri(self):
        """Gets the storage_uri of this InferenceServicePredictor.  # noqa: E501


        :return: The storage_uri of this InferenceServicePredictor.  # noqa: E501
        :rtype: str
        """
        return self._storage_uri

    @storage_uri.setter
    def storage_uri(self, storage_uri):
        """Sets the storage_uri of this InferenceServicePredictor.


        :param storage_uri: The storage_uri of this InferenceServicePredictor.  # noqa: E501
        :type: str
        """

        self._storage_uri = storage_uri

    @property
    def node_selector(self):
        """Gets the node_selector of this InferenceServicePredictor.  # noqa: E501


        :return: The node_selector of this InferenceServicePredictor.  # noqa: E501
        :rtype: str
        """
        return self._node_selector

    @node_selector.setter
    def node_selector(self, node_selector):
        """Sets the node_selector of this InferenceServicePredictor.


        :param node_selector: The node_selector of this InferenceServicePredictor.  # noqa: E501
        :type: str
        """

        self._node_selector = node_selector

    @property
    def min_cpu(self):
        """Gets the min_cpu of this InferenceServicePredictor.  # noqa: E501


        :return: The min_cpu of this InferenceServicePredictor.  # noqa: E501
        :rtype: str
        """
        return self._min_cpu

    @min_cpu.setter
    def min_cpu(self, min_cpu):
        """Sets the min_cpu of this InferenceServicePredictor.


        :param min_cpu: The min_cpu of this InferenceServicePredictor.  # noqa: E501
        :type: str
        """

        self._min_cpu = min_cpu

    @property
    def min_memory(self):
        """Gets the min_memory of this InferenceServicePredictor.  # noqa: E501


        :return: The min_memory of this InferenceServicePredictor.  # noqa: E501
        :rtype: str
        """
        return self._min_memory

    @min_memory.setter
    def min_memory(self, min_memory):
        """Sets the min_memory of this InferenceServicePredictor.


        :param min_memory: The min_memory of this InferenceServicePredictor.  # noqa: E501
        :type: str
        """

        self._min_memory = min_memory

    @property
    def max_cpu(self):
        """Gets the max_cpu of this InferenceServicePredictor.  # noqa: E501


        :return: The max_cpu of this InferenceServicePredictor.  # noqa: E501
        :rtype: str
        """
        return self._max_cpu

    @max_cpu.setter
    def max_cpu(self, max_cpu):
        """Sets the max_cpu of this InferenceServicePredictor.


        :param max_cpu: The max_cpu of this InferenceServicePredictor.  # noqa: E501
        :type: str
        """

        self._max_cpu = max_cpu

    @property
    def max_memory(self):
        """Gets the max_memory of this InferenceServicePredictor.  # noqa: E501


        :return: The max_memory of this InferenceServicePredictor.  # noqa: E501
        :rtype: str
        """
        return self._max_memory

    @max_memory.setter
    def max_memory(self, max_memory):
        """Sets the max_memory of this InferenceServicePredictor.


        :param max_memory: The max_memory of this InferenceServicePredictor.  # noqa: E501
        :type: str
        """

        self._max_memory = max_memory

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InferenceServicePredictor):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InferenceServicePredictor):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import onepanel.core.api
from onepanel.core.api.api.file_service_api import FileServiceApi  # noqa: E501
from onepanel.core.api.rest import ApiException


class TestFileServiceApi(unittest.TestCase):
    """FileServiceApi unit test stubs"""

    def setUp(self):
        self.api = onepanel.core.api.api.file_service_api.FileServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_object_download_presigned_url(self):
        """Test case for get_object_download_presigned_url

        """
        pass

    def test_list_files(self):
        """Test case for list_files

        """
        pass


if __name__ == '__main__':
    unittest.main()



import os.path
import onepanel.core.api

from onepanel.core.api.rest import ApiException
from onepanel.core.error import InvalidCredentialsException, MissingHostException, MissingTokenException

LOCAL_TOKEN_PATH = '/var/run/secrets/kubernetes.io/serviceaccount/token'


def get_access_token(username=None, token=None, skip_local_check=False, host=None):
    if not skip_local_check and os.path.exists(LOCAL_TOKEN_PATH):
        with open(LOCAL_TOKEN_PATH) as f:
            return f.read()

    if host is None:
        host = os.getenv('ONEPANEL_API_URL')
        if host is None:
            raise MissingHostException()

    if token is None:
        raise MissingTokenException('Token not set and no token found on system')

    configuration = onepanel.core.api.Configuration(host=host)
    configuration.api_key_prefix['authorization'] = 'Bearer'

    with onepanel.core.api.ApiClient(configuration) as api_client:
        try:
            api_instance = onepanel.core.api.AuthServiceApi(api_client)
            body = onepanel.core.api.GetAccessTokenRequest(username=username, token=token)
            api_response = api_instance.get_access_token(body)
            return api_response.access_token
        except ApiException as e:
            if e.status == 400:
                raise InvalidCredentialsException('The provided credentials are invalid')

            raise e


def get_infer_token(username=None, password=None, skip_local_check=False, host=None):
    if not skip_local_check and os.path.exists(LOCAL_TOKEN_PATH):
        with open(LOCAL_TOKEN_PATH) as f:
            return f.read()

    if host is None:
        host = os.getenv('ONEPANEL_API_URL')
        if host is None:
            raise MissingHostException()

    if password is None:
        raise MissingTokenException('password not set')

    configuration = onepanel.core.api.Configuration(host=host)
    configuration.api_key_prefix['authorization'] = 'Bearer'

    with onepanel.core.api.ApiClient(configuration) as api_client:
        try:
            api_instance = onepanel.core.api.AuthServiceApi(api_client)
            body = onepanel.core.api.GetInferTokenRequest(username=username, password=password)
            api_response = api_instance.get_infer_token(body)
            return api_response.access_token
        except ApiException as e:
            if e.status == 400:
                raise InvalidCredentialsException('The provided credentials are invalid')

            raise e


# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onepanel.core.api
from onepanel.core.api.models.workspace import Workspace  # noqa: E501
from onepanel.core.api.rest import ApiException

class TestWorkspace(unittest.TestCase):
    """Workspace unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Workspace
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = onepanel.core.api.models.workspace.Workspace()  # noqa: E501
        if include_optional :
            return Workspace(
                uid = '0', 
                name = '0', 
                version = '0', 
                created_at = '0', 
                parameters = [
                    onepanel.core.api.models.parameter.Parameter(
                        name = '0', 
                        value = '0', 
                        type = '0', 
                        display_name = '0', 
                        hint = '0', 
                        required = True, 
                        visibility = '0', 
                        options = [
                            onepanel.core.api.models.parameter_option.ParameterOption(
                                name = '0', 
                                value = '0', )
                            ], )
                    ], 
                workspace_template = onepanel.core.api.models.workspace_template.WorkspaceTemplate(
                    uid = '0', 
                    name = '0', 
                    version = '0', 
                    manifest = '0', 
                    is_latest = True, 
                    created_at = '0', 
                    workflow_template = onepanel.core.api.models.workflow_template.WorkflowTemplate(
                        created_at = '0', 
                        modified_at = '0', 
                        uid = '0', 
                        name = '0', 
                        version = '0', 
                        versions = '0', 
                        manifest = '0', 
                        is_latest = True, 
                        is_archived = True, 
                        labels = [
                            onepanel.core.api.models.key_value.KeyValue(
                                key = '0', 
                                value = '0', )
                            ], 
                        stats = onepanel.core.api.models.workflow_execution_statistic_report.WorkflowExecutionStatisticReport(
                            total = 56, 
                            last_executed = '0', 
                            running = 56, 
                            completed = 56, 
                            failed = 56, 
                            terminated = 56, ), 
                        cron_stats = onepanel.core.api.models.cron_workflow_statistics_report.CronWorkflowStatisticsReport(
                            total = 56, ), 
                        parameters = [
                            onepanel.core.api.models.parameter.Parameter(
                                name = '0', 
                                value = '0', 
                                type = '0', 
                                display_name = '0', 
                                hint = '0', 
                                required = True, 
                                visibility = '0', 
                                options = [
                                    onepanel.core.api.models.parameter_option.ParameterOption(
                                        name = '0', 
                                        value = '0', )
                                    ], )
                            ], 
                        description = '0', ), 
                    labels = [
                        onepanel.core.api.models.key_value.KeyValue(
                            key = '0', 
                            value = '0', )
                        ], 
                    is_archived = True, 
                    description = '0', ), 
                status = onepanel.core.api.models.workspace_status.WorkspaceStatus(
                    phase = '0', 
                    started_at = '0', 
                    paused_at = '0', 
                    terminated_at = '0', ), 
                labels = [
                    onepanel.core.api.models.key_value.KeyValue(
                        key = '0', 
                        value = '0', )
                    ], 
                url = '0', 
                template_parameters = [
                    onepanel.core.api.models.parameter.Parameter(
                        name = '0', 
                        value = '0', 
                        type = '0', 
                        display_name = '0', 
                        hint = '0', 
                        required = True, 
                        visibility = '0', 
                        options = [
                            onepanel.core.api.models.parameter_option.ParameterOption(
                                name = '0', 
                                value = '0', )
                            ], )
                    ], 
                workspace_components = [
                    onepanel.core.api.models.workspace_component.WorkspaceComponent(
                        name = '0', 
                        url = '0', )
                    ], 
                machine_type = onepanel.core.api.models.machine_type.MachineType(
                    name = '0', 
                    value = '0', )
            )
        else :
            return Workspace(
        )

    def testWorkspace(self):
        """Test Workspace"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onepanel.core.api
from onepanel.core.api.models.add_workflow_executions_metrics_request import AddWorkflowExecutionsMetricsRequest  # noqa: E501
from onepanel.core.api.rest import ApiException

class TestAddWorkflowExecutionsMetricsRequest(unittest.TestCase):
    """AddWorkflowExecutionsMetricsRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AddWorkflowExecutionsMetricsRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = onepanel.core.api.models.add_workflow_executions_metrics_request.AddWorkflowExecutionsMetricsRequest()  # noqa: E501
        if include_optional :
            return AddWorkflowExecutionsMetricsRequest(
                namespace = '0', 
                uid = '0', 
                override = True, 
                metrics = [
                    onepanel.core.api.models.metric.Metric(
                        name = '0', 
                        value = 1.337, 
                        format = '0', )
                    ]
            )
        else :
            return AddWorkflowExecutionsMetricsRequest(
        )

    def testAddWorkflowExecutionsMetricsRequest(self):
        """Test AddWorkflowExecutionsMetricsRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from onepanel.core.api.configuration import Configuration


class ListWorkflowExecutionsResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'count': 'int',
        'workflow_executions': 'list[WorkflowExecution]',
        'page': 'int',
        'pages': 'int',
        'total_count': 'int',
        'total_available_count': 'int'
    }

    attribute_map = {
        'count': 'count',
        'workflow_executions': 'workflowExecutions',
        'page': 'page',
        'pages': 'pages',
        'total_count': 'totalCount',
        'total_available_count': 'totalAvailableCount'
    }

    def __init__(self, count=None, workflow_executions=None, page=None, pages=None, total_count=None, total_available_count=None, local_vars_configuration=None):  # noqa: E501
        """ListWorkflowExecutionsResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._count = None
        self._workflow_executions = None
        self._page = None
        self._pages = None
        self._total_count = None
        self._total_available_count = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if workflow_executions is not None:
            self.workflow_executions = workflow_executions
        if page is not None:
            self.page = page
        if pages is not None:
            self.pages = pages
        if total_count is not None:
            self.total_count = total_count
        if total_available_count is not None:
            self.total_available_count = total_available_count

    @property
    def count(self):
        """Gets the count of this ListWorkflowExecutionsResponse.  # noqa: E501


        :return: The count of this ListWorkflowExecutionsResponse.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListWorkflowExecutionsResponse.


        :param count: The count of this ListWorkflowExecutionsResponse.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def workflow_executions(self):
        """Gets the workflow_executions of this ListWorkflowExecutionsResponse.  # noqa: E501


        :return: The workflow_executions of this ListWorkflowExecutionsResponse.  # noqa: E501
        :rtype: list[WorkflowExecution]
        """
        return self._workflow_executions

    @workflow_executions.setter
    def workflow_executions(self, workflow_executions):
        """Sets the workflow_executions of this ListWorkflowExecutionsResponse.


        :param workflow_executions: The workflow_executions of this ListWorkflowExecutionsResponse.  # noqa: E501
        :type: list[WorkflowExecution]
        """

        self._workflow_executions = workflow_executions

    @property
    def page(self):
        """Gets the page of this ListWorkflowExecutionsResponse.  # noqa: E501


        :return: The page of this ListWorkflowExecutionsResponse.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this ListWorkflowExecutionsResponse.


        :param page: The page of this ListWorkflowExecutionsResponse.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def pages(self):
        """Gets the pages of this ListWorkflowExecutionsResponse.  # noqa: E501


        :return: The pages of this ListWorkflowExecutionsResponse.  # noqa: E501
        :rtype: int
        """
        return self._pages

    @pages.setter
    def pages(self, pages):
        """Sets the pages of this ListWorkflowExecutionsResponse.


        :param pages: The pages of this ListWorkflowExecutionsResponse.  # noqa: E501
        :type: int
        """

        self._pages = pages

    @property
    def total_count(self):
        """Gets the total_count of this ListWorkflowExecutionsResponse.  # noqa: E501


        :return: The total_count of this ListWorkflowExecutionsResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ListWorkflowExecutionsResponse.


        :param total_count: The total_count of this ListWorkflowExecutionsResponse.  # noqa: E501
        :type: int
        """

        self._total_count = total_count

    @property
    def total_available_count(self):
        """Gets the total_available_count of this ListWorkflowExecutionsResponse.  # noqa: E501


        :return: The total_available_count of this ListWorkflowExecutionsResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_available_count

    @total_available_count.setter
    def total_available_count(self, total_available_count):
        """Sets the total_available_count of this ListWorkflowExecutionsResponse.


        :param total_available_count: The total_available_count of this ListWorkflowExecutionsResponse.  # noqa: E501
        :type: int
        """

        self._total_available_count = total_available_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListWorkflowExecutionsResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListWorkflowExecutionsResponse):
            return True

        return self.to_dict() != other.to_dict()



import logging
import pyaml
import os
import json
import zlib
from couler.argo_submitter import ArgoSubmitter
import onepanel.core.api
from onepanel.core.api.rest import ApiException
from onepanel.core.error import LongWorkflowNameException
from onepanel.core.auth import get_access_token


class Submitter(ArgoSubmitter):
    """A submitter which submits a workflow to Onepanel"""
    def __init__(self, workflow_name, username=None, token=None, host=None):
        if len(workflow_name) >= 20:
            raise LongWorkflowNameException('workflow_name must be 20 characters or less.')
        # If token and api_url are not passed in, use the values from token file and environment variable
        # If those don't exist, throw an exception
        self.namespace = os.getenv('ONEPANEL_RESOURCE_NAMESPACE')
        self.workflow_name = workflow_name

        self.configuration = onepanel.core.api.Configuration(host)
        logging.basicConfig(level=logging.INFO)

        self.configuration.api_key['authorization'] = get_access_token(username, token, host=host)
        self.configuration.api_key_prefix['authorization'] = 'Bearer'
        logging.info('Initialized')

    def _get_workflow_template(self, namespace, name):
        """
        Attempts to get the workflow template from the API.
        If the template exists, it is returned.
        If it does not, None is returned.
        """
        try:
            with onepanel.core.api.ApiClient(self.configuration) as api_client:
                api_instance = onepanel.core.api.WorkflowTemplateServiceApi(api_client)
                api_response = api_instance.get_workflow_template(namespace, name)
                return api_response
        except ApiException as e:
            if e.status == 404:
                return None
        return None

    def _are_workflow_template_manifests_equal(self, workflow_template, manifest):
        """
        Compare the crc32 hash of the workflow_template manifest and the input manifest
        If they are the same (same contents) return true, false otherwise.
        If workflow_template is None, false is automatically returned.
        """
        if workflow_template is None:
            return False
        yaml_str = workflow_template.to_dict()['manifest']
        hash1 = str(zlib.crc32(manifest.encode()))
        hash2 = str(zlib.crc32(yaml_str.encode()))
        return hash1 == hash2

    def _create_workflow_template(self, namespace, body):
        with onepanel.core.api.ApiClient(self.configuration) as api_client:
            api_instance = onepanel.core.api.WorkflowTemplateServiceApi(api_client)
            workflow_template = api_instance.create_workflow_template(
                namespace,
                body
            )
            return workflow_template

    def _create_template_version(self, namespace, workflow_template_uid, body):
        with onepanel.core.api.ApiClient(self.configuration) as api_client:
            api_instance = onepanel.core.api.WorkflowTemplateServiceApi(api_client)
            api_instance.create_workflow_template_version(namespace, workflow_template_uid, body)

    def _execute_workflow(self, namespace, workflow_template_uid):
        with onepanel.core.api.ApiClient(self.configuration) as api_client:
            api_instance = onepanel.core.api.WorkflowServiceApi(api_client)
            body = onepanel.core.api.CreateWorkflowExecutionBody(
                parameters=[],
                workflow_template_uid=workflow_template_uid,
                labels=[{'key': 'created-by', 'value': 'couler'}])
            return api_instance.create_workflow_execution(namespace, body)

    def _get_token(self, host, username, token):
        with onepanel.core.api.ApiClient(self.configuration) as api_client:
            api_instance = onepanel.core.api.AuthServiceApi(api_client)
            body = onepanel.core.api.GetAccessTokenRequest(username, token)
            return api_instance.get_access_token(body).to_dict()['access_token']

    def template_to_argo(self, workflow_yaml):
        output_dict = json.loads(json.dumps(workflow_yaml))
        yaml = output_dict['spec']
        manifest = pyaml.dump(yaml)
        return manifest

    def submit(self, workflow_yaml, secrets=None):
        if secrets is None:
            secrets = []

        for secret in secrets:
            self._create_secret(secret.to_yaml())
        manifest = self.template_to_argo(workflow_yaml)
        body = onepanel.core.api.WorkflowTemplate(
            manifest=manifest,
            name=self.workflow_name,
            labels=[{'key': 'created-by', 'value': 'couler'}]
        )
        workflow_template = self._get_workflow_template(self.namespace, self.workflow_name)
        # If we don't have a template, create one
        if workflow_template is None:
            workflow_template = self._create_workflow_template(self.namespace, body)
            logging.info('Workflow Template Created')
        elif not self._are_workflow_template_manifests_equal(workflow_template, manifest):
            # The contents are different, so create a new version.
            # If the contents are the same, no need for a new version.
            self._create_template_version(self.namespace, self.workflow_name, body)
            logging.info('Workflow Template updated')
        self._execute_workflow(self.namespace, workflow_template.uid)
        logging.info('Workflow Executed')



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from onepanel.core.api.api_client import ApiClient
from onepanel.core.api.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class WorkspaceServiceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_workspace(self, namespace, body, **kwargs):  # noqa: E501
        """create_workspace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_workspace(namespace, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param CreateWorkspaceBody body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Workspace
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_workspace_with_http_info(namespace, body, **kwargs)  # noqa: E501

    def create_workspace_with_http_info(self, namespace, body, **kwargs):  # noqa: E501
        """create_workspace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_workspace_with_http_info(namespace, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param CreateWorkspaceBody body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Workspace, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_workspace" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `create_workspace`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `create_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/workspaces', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Workspace',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_workspace(self, namespace, uid, **kwargs):  # noqa: E501
        """delete_workspace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_workspace(namespace, uid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_workspace_with_http_info(namespace, uid, **kwargs)  # noqa: E501

    def delete_workspace_with_http_info(self, namespace, uid, **kwargs):  # noqa: E501
        """delete_workspace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_workspace_with_http_info(namespace, uid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'uid'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_workspace" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `delete_workspace`")  # noqa: E501
        # verify the required parameter 'uid' is set
        if self.api_client.client_side_validation and ('uid' not in local_var_params or  # noqa: E501
                                                        local_var_params['uid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `uid` when calling `delete_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'uid' in local_var_params:
            path_params['uid'] = local_var_params['uid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/workspaces/{uid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workspace(self, namespace, uid, **kwargs):  # noqa: E501
        """get_workspace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workspace(namespace, uid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Workspace
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_workspace_with_http_info(namespace, uid, **kwargs)  # noqa: E501

    def get_workspace_with_http_info(self, namespace, uid, **kwargs):  # noqa: E501
        """get_workspace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workspace_with_http_info(namespace, uid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Workspace, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'uid'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workspace" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `get_workspace`")  # noqa: E501
        # verify the required parameter 'uid' is set
        if self.api_client.client_side_validation and ('uid' not in local_var_params or  # noqa: E501
                                                        local_var_params['uid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `uid` when calling `get_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'uid' in local_var_params:
            path_params['uid'] = local_var_params['uid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/workspaces/{uid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Workspace',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workspace_container_logs(self, namespace, uid, container_name, **kwargs):  # noqa: E501
        """get_workspace_container_logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workspace_container_logs(namespace, uid, container_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param str container_name: (required)
        :param str since_time:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StreamResultOfLogStreamResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_workspace_container_logs_with_http_info(namespace, uid, container_name, **kwargs)  # noqa: E501

    def get_workspace_container_logs_with_http_info(self, namespace, uid, container_name, **kwargs):  # noqa: E501
        """get_workspace_container_logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workspace_container_logs_with_http_info(namespace, uid, container_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param str container_name: (required)
        :param str since_time:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StreamResultOfLogStreamResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'uid',
            'container_name',
            'since_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workspace_container_logs" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `get_workspace_container_logs`")  # noqa: E501
        # verify the required parameter 'uid' is set
        if self.api_client.client_side_validation and ('uid' not in local_var_params or  # noqa: E501
                                                        local_var_params['uid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `uid` when calling `get_workspace_container_logs`")  # noqa: E501
        # verify the required parameter 'container_name' is set
        if self.api_client.client_side_validation and ('container_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['container_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `container_name` when calling `get_workspace_container_logs`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'uid' in local_var_params:
            path_params['uid'] = local_var_params['uid']  # noqa: E501
        if 'container_name' in local_var_params:
            path_params['containerName'] = local_var_params['container_name']  # noqa: E501

        query_params = []
        if 'since_time' in local_var_params and local_var_params['since_time'] is not None:  # noqa: E501
            query_params.append(('sinceTime', local_var_params['since_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/workspaces/{uid}/containers/{containerName}/logs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StreamResultOfLogStreamResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workspace_statistics_for_namespace(self, namespace, **kwargs):  # noqa: E501
        """get_workspace_statistics_for_namespace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workspace_statistics_for_namespace(namespace, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GetWorkspaceStatisticsForNamespaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_workspace_statistics_for_namespace_with_http_info(namespace, **kwargs)  # noqa: E501

    def get_workspace_statistics_for_namespace_with_http_info(self, namespace, **kwargs):  # noqa: E501
        """get_workspace_statistics_for_namespace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workspace_statistics_for_namespace_with_http_info(namespace, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GetWorkspaceStatisticsForNamespaceResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workspace_statistics_for_namespace" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `get_workspace_statistics_for_namespace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/workspace/statistics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetWorkspaceStatisticsForNamespaceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_workspaces(self, namespace, **kwargs):  # noqa: E501
        """list_workspaces  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_workspaces(namespace, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param int page_size:
        :param int page:
        :param str order:
        :param str labels:
        :param str phase:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ListWorkspaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_workspaces_with_http_info(namespace, **kwargs)  # noqa: E501

    def list_workspaces_with_http_info(self, namespace, **kwargs):  # noqa: E501
        """list_workspaces  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_workspaces_with_http_info(namespace, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param int page_size:
        :param int page:
        :param str order:
        :param str labels:
        :param str phase:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ListWorkspaceResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'page_size',
            'page',
            'order',
            'labels',
            'phase'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_workspaces" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `list_workspaces`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501

        query_params = []
        if 'page_size' in local_var_params and local_var_params['page_size'] is not None:  # noqa: E501
            query_params.append(('pageSize', local_var_params['page_size']))  # noqa: E501
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'order' in local_var_params and local_var_params['order'] is not None:  # noqa: E501
            query_params.append(('order', local_var_params['order']))  # noqa: E501
        if 'labels' in local_var_params and local_var_params['labels'] is not None:  # noqa: E501
            query_params.append(('labels', local_var_params['labels']))  # noqa: E501
        if 'phase' in local_var_params and local_var_params['phase'] is not None:  # noqa: E501
            query_params.append(('phase', local_var_params['phase']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/workspaces', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListWorkspaceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_workspaces_field(self, namespace, field_name, **kwargs):  # noqa: E501
        """list_workspaces_field  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_workspaces_field(namespace, field_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str field_name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ListWorkspacesFieldResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_workspaces_field_with_http_info(namespace, field_name, **kwargs)  # noqa: E501

    def list_workspaces_field_with_http_info(self, namespace, field_name, **kwargs):  # noqa: E501
        """list_workspaces_field  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_workspaces_field_with_http_info(namespace, field_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str field_name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ListWorkspacesFieldResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'field_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_workspaces_field" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `list_workspaces_field`")  # noqa: E501
        # verify the required parameter 'field_name' is set
        if self.api_client.client_side_validation and ('field_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['field_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `field_name` when calling `list_workspaces_field`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'field_name' in local_var_params:
            path_params['fieldName'] = local_var_params['field_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta/{namespace}/field/workspaces/{fieldName}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListWorkspacesFieldResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def pause_workspace(self, namespace, uid, **kwargs):  # noqa: E501
        """pause_workspace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pause_workspace(namespace, uid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.pause_workspace_with_http_info(namespace, uid, **kwargs)  # noqa: E501

    def pause_workspace_with_http_info(self, namespace, uid, **kwargs):  # noqa: E501
        """pause_workspace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pause_workspace_with_http_info(namespace, uid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'uid'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method pause_workspace" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `pause_workspace`")  # noqa: E501
        # verify the required parameter 'uid' is set
        if self.api_client.client_side_validation and ('uid' not in local_var_params or  # noqa: E501
                                                        local_var_params['uid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `uid` when calling `pause_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'uid' in local_var_params:
            path_params['uid'] = local_var_params['uid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/workspaces/{uid}/pause', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resume_workspace(self, namespace, uid, body, **kwargs):  # noqa: E501
        """resume_workspace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_workspace(namespace, uid, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param UpdateWorkspaceBody body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.resume_workspace_with_http_info(namespace, uid, body, **kwargs)  # noqa: E501

    def resume_workspace_with_http_info(self, namespace, uid, body, **kwargs):  # noqa: E501
        """resume_workspace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_workspace_with_http_info(namespace, uid, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param UpdateWorkspaceBody body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'uid',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resume_workspace" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `resume_workspace`")  # noqa: E501
        # verify the required parameter 'uid' is set
        if self.api_client.client_side_validation and ('uid' not in local_var_params or  # noqa: E501
                                                        local_var_params['uid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `uid` when calling `resume_workspace`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `resume_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'uid' in local_var_params:
            path_params['uid'] = local_var_params['uid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/workspaces/{uid}/resume', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retry_last_workspace_action(self, namespace, uid, **kwargs):  # noqa: E501
        """retry_last_workspace_action  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retry_last_workspace_action(namespace, uid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.retry_last_workspace_action_with_http_info(namespace, uid, **kwargs)  # noqa: E501

    def retry_last_workspace_action_with_http_info(self, namespace, uid, **kwargs):  # noqa: E501
        """retry_last_workspace_action  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retry_last_workspace_action_with_http_info(namespace, uid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'uid'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retry_last_workspace_action" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `retry_last_workspace_action`")  # noqa: E501
        # verify the required parameter 'uid' is set
        if self.api_client.client_side_validation and ('uid' not in local_var_params or  # noqa: E501
                                                        local_var_params['uid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `uid` when calling `retry_last_workspace_action`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'uid' in local_var_params:
            path_params['uid'] = local_var_params['uid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/workspaces/{uid}/retry', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_workspace(self, namespace, uid, body, **kwargs):  # noqa: E501
        """update_workspace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_workspace(namespace, uid, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param UpdateWorkspaceBody body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_workspace_with_http_info(namespace, uid, body, **kwargs)  # noqa: E501

    def update_workspace_with_http_info(self, namespace, uid, body, **kwargs):  # noqa: E501
        """update_workspace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_workspace_with_http_info(namespace, uid, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param UpdateWorkspaceBody body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'uid',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_workspace" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `update_workspace`")  # noqa: E501
        # verify the required parameter 'uid' is set
        if self.api_client.client_side_validation and ('uid' not in local_var_params or  # noqa: E501
                                                        local_var_params['uid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `uid` when calling `update_workspace`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `update_workspace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'uid' in local_var_params:
            path_params['uid'] = local_var_params['uid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/workspaces/{uid}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_workspace_status(self, namespace, uid, body, **kwargs):  # noqa: E501
        """update_workspace_status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_workspace_status(namespace, uid, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param WorkspaceStatus body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_workspace_status_with_http_info(namespace, uid, body, **kwargs)  # noqa: E501

    def update_workspace_status_with_http_info(self, namespace, uid, body, **kwargs):  # noqa: E501
        """update_workspace_status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_workspace_status_with_http_info(namespace, uid, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str namespace: (required)
        :param str uid: (required)
        :param WorkspaceStatus body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'namespace',
            'uid',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_workspace_status" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if self.api_client.client_side_validation and ('namespace' not in local_var_params or  # noqa: E501
                                                        local_var_params['namespace'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `namespace` when calling `update_workspace_status`")  # noqa: E501
        # verify the required parameter 'uid' is set
        if self.api_client.client_side_validation and ('uid' not in local_var_params or  # noqa: E501
                                                        local_var_params['uid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `uid` when calling `update_workspace_status`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `update_workspace_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'uid' in local_var_params:
            path_params['uid'] = local_var_params['uid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/apis/v1beta1/{namespace}/workspaces/{uid}/status', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)




class OnepanelException(Exception):
    """Base-class for all exceptions raised by the OnepanelSubmitter"""


class MissingUsernameException(OnepanelException):
    """
    Happens when there is no provided username
    """

class MissingTokenException(OnepanelException):
    """
    Happens when there is no provided token and one can't be found on the system.
    """


class MissingHostException(OnepanelException):
    """
    Happens when there is no provided host and can't be found on the system
    """


class InvalidCredentialsException(OnepanelException):
    """
    Happens when the credentials to get the authentication token are incorrect.
    """


class LongWorkflowNameException(OnepanelException):
    """
    Happens when the workflow name is too long - which is >= 20 characters.
    """


# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Generated by: https://openapi-generator.tech
"""


import sys
import subprocess
from setuptools import setup, find_packages  # noqa: H301
from setuptools.command.install import install as InstallCommand

NAME = "aimp-sdk"
VERSION = "0.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

class Install(InstallCommand):
    """ Customized setuptools install command which uses pip. """

    def run(self, *args, **kwargs):
        subprocess.call([sys.executable, '-m', 'pip', 'install','git+https://github.com/onepanelio/couler@v0.1.1rc8'])
        InstallCommand.run(self, *args, **kwargs)

setup(
    name=NAME,
    version=VERSION,
    description="Python SDK for Onepanel",
    author="Onepanel, Inc.",
    author_email="support@onepanel.io",
    url="https://github.com/onepanelio/core",
    keywords=["onepanel", "computer-vision", "deep-learning", "ai", "mlops"],
    install_requires=REQUIRES,
    cmdclass={
        'install': Install,
    },
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    long_description="""\
    Python SDK for Onepanel - Production scale vision AI platform with fully integrated components for model building, automated labeling, data processing and model training pipelines.
    """
)



import os

from IPython.core.magic import (Magics, magics_class, line_magic)
from IPython.display import IFrame

@magics_class
class IPythonMagics(Magics):

    @line_magic
    def nni_ui(self, line):
        domain = os.getenv('ONEPANEL_DOMAIN', '127.0.0.1')

        if domain == '127.0.0.1':
            src = '//{domain}:8080'.format(domain=domain)
        else:
            src = '//{uid}--{namespace}.{domain}/nni'.format(
                uid=os.getenv('ONEPANEL_RESOURCE_UID'),
                namespace=os.getenv('ONEPANEL_RESOURCE_NAMESPACE'),
                domain=domain)
        return IFrame(src=src, width='100%', height='500px')



# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 1.0.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from onepanel.core.api.configuration import Configuration


class WorkspaceStatisticReport(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'total': 'int',
        'last_created': 'str',
        'launching': 'int',
        'running': 'int',
        'updating': 'int',
        'pausing': 'int',
        'paused': 'int',
        'terminating': 'int',
        'terminated': 'int',
        'failed_to_pause': 'int',
        'failed_to_resume': 'int',
        'failed_to_terminate': 'int',
        'failed_to_launch': 'int',
        'failed_to_update': 'int',
        'failed': 'int'
    }

    attribute_map = {
        'total': 'total',
        'last_created': 'lastCreated',
        'launching': 'launching',
        'running': 'running',
        'updating': 'updating',
        'pausing': 'pausing',
        'paused': 'paused',
        'terminating': 'terminating',
        'terminated': 'terminated',
        'failed_to_pause': 'failedToPause',
        'failed_to_resume': 'failedToResume',
        'failed_to_terminate': 'failedToTerminate',
        'failed_to_launch': 'failedToLaunch',
        'failed_to_update': 'failedToUpdate',
        'failed': 'failed'
    }

    def __init__(self, total=None, last_created=None, launching=None, running=None, updating=None, pausing=None, paused=None, terminating=None, terminated=None, failed_to_pause=None, failed_to_resume=None, failed_to_terminate=None, failed_to_launch=None, failed_to_update=None, failed=None, local_vars_configuration=None):  # noqa: E501
        """WorkspaceStatisticReport - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._total = None
        self._last_created = None
        self._launching = None
        self._running = None
        self._updating = None
        self._pausing = None
        self._paused = None
        self._terminating = None
        self._terminated = None
        self._failed_to_pause = None
        self._failed_to_resume = None
        self._failed_to_terminate = None
        self._failed_to_launch = None
        self._failed_to_update = None
        self._failed = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if last_created is not None:
            self.last_created = last_created
        if launching is not None:
            self.launching = launching
        if running is not None:
            self.running = running
        if updating is not None:
            self.updating = updating
        if pausing is not None:
            self.pausing = pausing
        if paused is not None:
            self.paused = paused
        if terminating is not None:
            self.terminating = terminating
        if terminated is not None:
            self.terminated = terminated
        if failed_to_pause is not None:
            self.failed_to_pause = failed_to_pause
        if failed_to_resume is not None:
            self.failed_to_resume = failed_to_resume
        if failed_to_terminate is not None:
            self.failed_to_terminate = failed_to_terminate
        if failed_to_launch is not None:
            self.failed_to_launch = failed_to_launch
        if failed_to_update is not None:
            self.failed_to_update = failed_to_update
        if failed is not None:
            self.failed = failed

    @property
    def total(self):
        """Gets the total of this WorkspaceStatisticReport.  # noqa: E501


        :return: The total of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this WorkspaceStatisticReport.


        :param total: The total of this WorkspaceStatisticReport.  # noqa: E501
        :type: int
        """

        self._total = total

    @property
    def last_created(self):
        """Gets the last_created of this WorkspaceStatisticReport.  # noqa: E501


        :return: The last_created of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: str
        """
        return self._last_created

    @last_created.setter
    def last_created(self, last_created):
        """Sets the last_created of this WorkspaceStatisticReport.


        :param last_created: The last_created of this WorkspaceStatisticReport.  # noqa: E501
        :type: str
        """

        self._last_created = last_created

    @property
    def launching(self):
        """Gets the launching of this WorkspaceStatisticReport.  # noqa: E501


        :return: The launching of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: int
        """
        return self._launching

    @launching.setter
    def launching(self, launching):
        """Sets the launching of this WorkspaceStatisticReport.


        :param launching: The launching of this WorkspaceStatisticReport.  # noqa: E501
        :type: int
        """

        self._launching = launching

    @property
    def running(self):
        """Gets the running of this WorkspaceStatisticReport.  # noqa: E501


        :return: The running of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: int
        """
        return self._running

    @running.setter
    def running(self, running):
        """Sets the running of this WorkspaceStatisticReport.


        :param running: The running of this WorkspaceStatisticReport.  # noqa: E501
        :type: int
        """

        self._running = running

    @property
    def updating(self):
        """Gets the updating of this WorkspaceStatisticReport.  # noqa: E501


        :return: The updating of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: int
        """
        return self._updating

    @updating.setter
    def updating(self, updating):
        """Sets the updating of this WorkspaceStatisticReport.


        :param updating: The updating of this WorkspaceStatisticReport.  # noqa: E501
        :type: int
        """

        self._updating = updating

    @property
    def pausing(self):
        """Gets the pausing of this WorkspaceStatisticReport.  # noqa: E501


        :return: The pausing of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: int
        """
        return self._pausing

    @pausing.setter
    def pausing(self, pausing):
        """Sets the pausing of this WorkspaceStatisticReport.


        :param pausing: The pausing of this WorkspaceStatisticReport.  # noqa: E501
        :type: int
        """

        self._pausing = pausing

    @property
    def paused(self):
        """Gets the paused of this WorkspaceStatisticReport.  # noqa: E501


        :return: The paused of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: int
        """
        return self._paused

    @paused.setter
    def paused(self, paused):
        """Sets the paused of this WorkspaceStatisticReport.


        :param paused: The paused of this WorkspaceStatisticReport.  # noqa: E501
        :type: int
        """

        self._paused = paused

    @property
    def terminating(self):
        """Gets the terminating of this WorkspaceStatisticReport.  # noqa: E501


        :return: The terminating of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: int
        """
        return self._terminating

    @terminating.setter
    def terminating(self, terminating):
        """Sets the terminating of this WorkspaceStatisticReport.


        :param terminating: The terminating of this WorkspaceStatisticReport.  # noqa: E501
        :type: int
        """

        self._terminating = terminating

    @property
    def terminated(self):
        """Gets the terminated of this WorkspaceStatisticReport.  # noqa: E501


        :return: The terminated of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: int
        """
        return self._terminated

    @terminated.setter
    def terminated(self, terminated):
        """Sets the terminated of this WorkspaceStatisticReport.


        :param terminated: The terminated of this WorkspaceStatisticReport.  # noqa: E501
        :type: int
        """

        self._terminated = terminated

    @property
    def failed_to_pause(self):
        """Gets the failed_to_pause of this WorkspaceStatisticReport.  # noqa: E501


        :return: The failed_to_pause of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: int
        """
        return self._failed_to_pause

    @failed_to_pause.setter
    def failed_to_pause(self, failed_to_pause):
        """Sets the failed_to_pause of this WorkspaceStatisticReport.


        :param failed_to_pause: The failed_to_pause of this WorkspaceStatisticReport.  # noqa: E501
        :type: int
        """

        self._failed_to_pause = failed_to_pause

    @property
    def failed_to_resume(self):
        """Gets the failed_to_resume of this WorkspaceStatisticReport.  # noqa: E501


        :return: The failed_to_resume of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: int
        """
        return self._failed_to_resume

    @failed_to_resume.setter
    def failed_to_resume(self, failed_to_resume):
        """Sets the failed_to_resume of this WorkspaceStatisticReport.


        :param failed_to_resume: The failed_to_resume of this WorkspaceStatisticReport.  # noqa: E501
        :type: int
        """

        self._failed_to_resume = failed_to_resume

    @property
    def failed_to_terminate(self):
        """Gets the failed_to_terminate of this WorkspaceStatisticReport.  # noqa: E501


        :return: The failed_to_terminate of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: int
        """
        return self._failed_to_terminate

    @failed_to_terminate.setter
    def failed_to_terminate(self, failed_to_terminate):
        """Sets the failed_to_terminate of this WorkspaceStatisticReport.


        :param failed_to_terminate: The failed_to_terminate of this WorkspaceStatisticReport.  # noqa: E501
        :type: int
        """

        self._failed_to_terminate = failed_to_terminate

    @property
    def failed_to_launch(self):
        """Gets the failed_to_launch of this WorkspaceStatisticReport.  # noqa: E501


        :return: The failed_to_launch of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: int
        """
        return self._failed_to_launch

    @failed_to_launch.setter
    def failed_to_launch(self, failed_to_launch):
        """Sets the failed_to_launch of this WorkspaceStatisticReport.


        :param failed_to_launch: The failed_to_launch of this WorkspaceStatisticReport.  # noqa: E501
        :type: int
        """

        self._failed_to_launch = failed_to_launch

    @property
    def failed_to_update(self):
        """Gets the failed_to_update of this WorkspaceStatisticReport.  # noqa: E501


        :return: The failed_to_update of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: int
        """
        return self._failed_to_update

    @failed_to_update.setter
    def failed_to_update(self, failed_to_update):
        """Sets the failed_to_update of this WorkspaceStatisticReport.


        :param failed_to_update: The failed_to_update of this WorkspaceStatisticReport.  # noqa: E501
        :type: int
        """

        self._failed_to_update = failed_to_update

    @property
    def failed(self):
        """Gets the failed of this WorkspaceStatisticReport.  # noqa: E501


        :return: The failed of this WorkspaceStatisticReport.  # noqa: E501
        :rtype: int
        """
        return self._failed

    @failed.setter
    def failed(self, failed):
        """Sets the failed of this WorkspaceStatisticReport.


        :param failed: The failed of this WorkspaceStatisticReport.  # noqa: E501
        :type: int
        """

        self._failed = failed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkspaceStatisticReport):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkspaceStatisticReport):
            return True

        return self.to_dict() != other.to_dict()
